Rem Copyright - Relational Database Consultants, Inc.

Set Echo On

Undefine License_No
Set AutoCommit On

Create Sequence Table_Seq 
MaxValue 999999999
Cycle
NoCache
/ 

Create Sequence Column_Seq
MaxValue 999999999999
Cycle
NoCache
/

Create Sequence Audit_Seq
MaxValue 999999999999
Cycle
NoCache
/

Create Table RDC_Encrypt_License
(
	License_No								Number			Not Null,
	License_Type							Varchar2(30)	Not Null,
	Expiration_Date						Date				Not Null,
	Administration_Password				Raw(80)			Not Null,
	Default_Rollback_Segment			Varchar2(30),
	Encrypt_Null_Flag						Char(1),
	Use_RowID_For_Views					Char(1),
	Email_Address							Varchar2(255)
)
/

Create Table Encrypted_Table
(
	Table_Seq								Number(9)			Not Null,
	Table_Name								Varchar2(30)		Not Null,
	Table_Owner								Varchar2(30)		Not Null,
	View_Owner								Varchar2(30),
	View_Name								Varchar2(30),
	Update_Flag								Char(1),
	Encryption_Marker_Flag				Char(1),
	Index_Flag								Char(1),
	Trigger_Text							Clob,
	Time_Stamp								Date,
	Primary Key								(Table_Seq)
);

Create Table Valid_Encryption_Types
(
	Encryption_Type						Varchar2(30)		Not Null,
	Default_Key_Length					Number(4)			Not Null,
	Obfuscation_Multiple					Number(4)			Not Null,
	Modify_Column_Length					Char(1),
	Primary Key								(Encryption_Type)
);

Insert Into Valid_Encryption_Types Values ('DES', 				8, 	8, 	'X');
Insert Into Valid_Encryption_Types Values ('Triple DES3', 	8, 	8, 	'X');
Insert Into Valid_Encryption_Types Values ('Obfuscation', 	8, 	8, 	Null);
Insert Into Valid_Encryption_Types Values ('None', 			0, 	0, 	Null);


Commit;


Create Table Encrypted_Column
(
	Column_Seq								Number(12)			Not Null,
	Table_Seq								Number(9)			Not Null,
	Column_Name								Varchar2(30)		Not Null,
	Data_Type								Varchar2(30)		Not Null,
	Data_Length								Number(12)			Not Null,
	New_Data_Length						Number(12),
	Encryption_Type						Varchar2(30)		Not Null,
	Obfuscation_Multiple					Number(4)			Not Null,
	Default_Key_Length					Number(4) 			Not Null,
	Key_Value								Raw(256)				Not Null,
	New_Key_Value							Raw(256),
	Character_Set							Number(9)			Not Null,
	Column_Hash								Raw(256)				Not Null,
	HSM_Hash									Raw(256)				Not Null,
	Audit_Type								Char(1),
	Authorization_Flag					Char(1),
	Authorization_Hash					Raw(256),
	Default_Password						Raw(256)				Not Null,
	Delete_Flag								Char(1),
	Encryption_Marker_Flag				Char(1),
	Function_Index_Flag					Char(1),
	Salt_Flag								Char(1),
	Encrypt_Null_Flag						Char(1),
	Default_Mask							Raw(256)				Not Null,
	Pre_Registered_Flag					Char(1),
	Time_Stamp								Date,
	Primary Key								(Column_Seq),
	Foreign Key								(Table_Seq)
	References								Encrypted_Table(Table_Seq)
	On Delete Cascade
) 
Storage (Initial 1M Next 1M PctIncrease 0);	

Create Table Encrypted_Column_History
Storage (Initial 1M Next 1M PctIncrease 0)
As
Select * From RDC_Encrypt_User.Encrypted_Column;

Create Table Encrypted_Table_History
Storage (Initial 1M Next 1M PctIncrease 0)
As
Select * From RDC_Encrypt_User.Encrypted_Table;

Create Table Encrypted_Column_User
(
	Column_Seq								Number(12) 		Not Null,
	User_ID									Number			Not Null,
	Authorization_Type					Char(1)			Not Null,
	Authorization_Hash					Raw(256)			Not Null,
	Authorization_Password				Raw(256)			Not Null,
	Time_Stamp								Date				Not Null,
	Primary Key								(Column_Seq, User_ID),
	Foreign Key								(Column_Seq)
	References								Encrypted_Column(Column_Seq)
	On Delete Cascade
)
Storage (Initial 1M Next 1M PctIncrease 0);

Create Table Internal_Audit
(
	Audit_Seq							Number(12)			Not Null,
	Event_Message						Varchar2(2000)		Not Null,
	Message_Type						Char(1)				Not Null,
	Time_Stamp							Date					Not Null,
	User_Name							Varchar2(30)		Not Null,
	From_Terminal						Varchar2(255),
	From_Machine						Varchar2(255),
	OS_User								Varchar2(255),
	Calling_Program					Varchar2(255),
	Calling_Module						Varchar2(255),
	Logon_Time							Date,					
	SQL_Buffer							Varchar2(4000)
)
Storage (Initial 1M Next 1M PctIncrease 0);

Create Table Encrypt_Audit
(
	Audit_Seq							Number(12)			Not Null,
	Audit_Type							Char(1)				Not Null,
	Fail_Flag							Char(1),
	Table_Owner							Varchar2(30)		Not Null,
	Table_Name							Varchar2(30)		Not Null,
	Column_Name							Varchar2(30)		Not Null,
	Time_Stamp							Date					Not Null,
	User_Name							Varchar2(30)		Not Null,
	From_Terminal						Varchar2(255),
	From_Machine						Varchar2(255),
	OS_User								Varchar2(255),
	Calling_Program					Varchar2(255),
	Calling_Module						Varchar2(255),
	Logon_Time							Date
)
Storage (Initial 1M Next 1M PctIncrease 0);
